;
;	Graphic & Double Height character Test
;	V1.0 2024 TB
;

ACIA_S 		= $F000
ACIA_D 		= $F001
VIDEO_RAM	= $D000
KEYB 		= $FD00
mode		= $FC
mem		= $2000
RESET		= $FF00

START_ADR = $0350		; 

	.ORG	START_ADR
	
	
	

	Lda	#0
	sta	mode
	jsr	SET
	jsr	CLS

	jsr	SNUM		; Set 0..255 to screen
	jsr	KEYB		; wait for input
	cmp	#27
	beq	ESC


	lda	#$00	
L0:	jsr	CLHRS		; clear 8k of hires ram

	lda	#$01		; Set main display mode
	sta	mode
	jsr	SET

	JSR	KEYB		; wait for input
	cmp	#27
	beq	ESC

	lda	#$0		; 1st segment
	ldx	#$0
	jsr	CPSEG
	lda	#$1
	inx
	jsr	CPSEG

	inx
	inx
	
	lda	#$0		; 3rd segment
	inx
	jsr	CPSEG
	lda	#$1
	inx
	jsr	CPSEG

	lda	#$0		; 4th segment
	inx
	jsr	CPSEG
	lda	#$1
	inx
	jsr	CPSEG
	
	
	lda	#2
	jsr	DHF		; Create double font in segment 3
	
	JSR	KEYB		; wait for input
	cmp	#27
	beq	ESC

	
	jsr	TEST5		; Copy GR1 to 2nd Segment


	lda	#$20
	ldy	#$00		; Clear 32x32 Screen segment 3 with 00
LC:	sta	VIDEO_RAM+$200,y
	iny
	bne	LC
	
	JSR	SBTEXT		; Output samll and tall text
	JSR	KEYB		; wait for input
	cmp	#27
	beq	ESC
	
	jmp	L0

	
ESC:	lda	#$00
	sta	mode
	jsr	SET		; Char RAM 4th 1k
	jmp	RESET

; *****************************************************************************

SBTEXT:
	ldy	#$00
SB1:	lda	TEXT1,y			; normal text to display
	beq	SB2
	sta	VIDEO_RAM+$286,y
	iny
	bne	SB1
SB2:	iny				; tall text to display
SB3:	lda	TEXT1,y			; normal text to display
	beq	SB4
	sec
	sbc	#$20			; only characters between 20 and 5F
	cmp	#$60
	bcs	SB2
	asl
	ora	#$80			; select proper upper character code	
	sta	VIDEO_RAM+$266,y
	clc
	adc	#$01
	sta	VIDEO_RAM+$286,y
	iny
	bne	SB3
SB4:	rts

TEXT1:	.db "Normal or ",0
	.db "TALL !!",0

; ******************************************************************************

SNUM:
	ldy	#$00			; Set 32x32 Screen with 0,1,2,..

LSN:	tya
	sta	VIDEO_RAM,y
	sta	VIDEO_RAM+$100,y
	sta	VIDEO_RAM+$200,y
	sta	VIDEO_RAM+$300,y
	dey
	bne	LSN
	rts


; ******************************************************************************
		
CLS:
	lda	#$20
CLSA:	ldy	#$00			; Clear 32x32 Screen with $20

LCLS:
	sta	VIDEO_RAM,y
	sta	VIDEO_RAM+$100,y
	sta	VIDEO_RAM+$200,y
	sta	VIDEO_RAM+$300,y
	iny
	bne	LCLS
	rts

; ******************************************************************************
		
CLHRS:
	tax			; Clear 8K HiRes Screen with $ACCU
	lda	#$21
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$25
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$29
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$2D
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$31
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$35
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$39
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$3D
	sta	mode
	jsr	SET
	txa
	jmp	CLSA		; clear 1k segment of hires ram
	

; ******************************************************************************

CPSEG:	ldy	mode		; Copy 1k Character ROM of Segment A (0..3) to RAM X (0..7)
	and	#$03
	asl
	asl
	ora	#$20		; Char ROM first 1k
	sta	mode
	jsr	SET
	sty	mode		; restore for later
		
	ldy	#$0
CP1:	lda	VIDEO_RAM,y
	sta	mem,y
	lda	VIDEO_RAM+$100,y
	sta	mem+$100,y
	lda	VIDEO_RAM+$200,y
	sta	mem+$200,y
	lda	VIDEO_RAM+$300,y
	sta	mem+$300,y
	iny
	bne	CP1
	
	ldy	mode
	txa
	and	#$07
	asl
	asl
	ora	#$21
	sta	mode
	jsr	SET
	sty	mode
	
	ldy	#$0
CP2:	lda	mem,y
	sta	VIDEO_RAM,y
	lda	mem+$100,y
	sta	VIDEO_RAM+$100,y
	lda	mem+$200,y
	sta	VIDEO_RAM+$200,y
	lda	mem+$300,y
	sta	VIDEO_RAM+$300,y
	iny
	bne	CP2
	
	jmp	SET

; *****************************************************************************

DHF:			; Create 1k double height font in Segment RAM A (0..3)
			; Will modify upper 128 characters to double height (64 characters starting at 20 to 5F)
			; Top part is 80, bottom part is C0 and so on)
	pha		
	ldy	mode
	and	#$03
	asl
	asl
	asl
	ora	#$21
	sta	mode
	jsr	SET
	sty	mode
	
	ldy	#$0
DH1:	lda	VIDEO_RAM+$100,y		; getting 20 to 5F characters
	sta	mem,y
	lda	VIDEO_RAM+$200,y
	sta	mem+$100,y
	iny
	bne	DH1

	pla
	ldy	mode
	and	#$03
	asl
	asl
	asl
	clc
	adc	#$04				; next 1k segment for 80..FF
	ora	#$21
	sta	mode
	jsr	SET
	sty	mode	
		
	ldy	#$0
	ldx	#$0
DH2:	lda	mem,y
	sta	VIDEO_RAM,x
	sta	VIDEO_RAM+1,x
	lda	mem+$100,y
	sta	VIDEO_RAM+$200,x
	sta	VIDEO_RAM+$201,x
	iny
	inx
	inx
	bne	DH2
	
DH3:	lda	mem,y
	sta	VIDEO_RAM+$100,x
	sta	VIDEO_RAM+$101,x
	lda	mem+$100,y
	sta	VIDEO_RAM+$300,x
	sta	VIDEO_RAM+$301,x
	iny
	inx
	inx
	bne	DH3
	
	jmp	SET	

; ******************************************************************************

DEY1:	pha
	tya
	pha			; *** 1ms  DELAY (1ms times X) ***
DEY2:	ldy	#$C6
LDEY:
	dey
	bne	LDEY		; Loop back
	nop
	nop
	dex
	bne	DEY2		; Loop back
	pla
	tay
	pla
	rts	
	
; ******************************************************************************
SET:	lda $D000
        sta $D000
        lda $D3FF
        sta $D3FF
        lda mode
        sta $D3FF
        rts
        
; ********************* T0 ONLY SET TO mode 0 ts ********************************

TEST0:  lda	#$00
	sta	mode
	jsr	SET
	jmp	TEST0

; ********************* T1 LOAD/STORE 4 segments ********************************

TEST1:


T1:	lda	VIDEO_RAM+$80
	sta	VIDEO_RAM+$80

	lda	VIDEO_RAM+$180
	sta	VIDEO_RAM+$180

	lda	VIDEO_RAM+$280
	sta	VIDEO_RAM+$280

	lda	VIDEO_RAM+$380
	sta	VIDEO_RAM+$380

	jmp	T1
	
; ********************* T2 Increment byte and set mode 21 ***********************

TEST2:


T2:	inc	$D0E0
	lda	#$21
	sta	mode
	jsr	SET

	jmp	T2


; *********** T3 LOAD HIRES to mem, set mode 02 and write back to video ram *****

TEST3:

	lda	#$21
	sta	mode
	jsr	SET

	ldy	#0
read:	lda	VIDEO_RAM,y
	sta	mem,y
	lda	VIDEO_RAM+$100,y
	sta	mem+$100,y
	lda	VIDEO_RAM+$200,y
	sta	mem+$200,y
	lda	VIDEO_RAM+$300,y
	sta	mem+$300,y
	iny
	bne	read
	
	lda	#$00
	sta	mode
	jsr	SET
	
	ldy	#0
write:	lda	mem,y
	sta	VIDEO_RAM,y
	lda	mem+$100,y
	sta	VIDEO_RAM+$100,y
	lda	mem+$200,y
	sta	VIDEO_RAM+$200,y
	lda	mem+$300,y
	sta	VIDEO_RAM+$300,y
	iny
	bne	write
	rts


; ********************* T4 stop and set mode 1 ***********************

TEST4:
	lda	#$01
	sta	mode
	jsr	SET
stop:	jmp	stop	


; ********************* T5 Transfer GR1 to 2nd Segment ***********************

TEST5:

	ldy	mode
	lda	#$29
	sta	mode
	jsr	SET
	sty	mode

	ldy	#$0
T51:	lda	GR1,y
	sta	VIDEO_RAM,y
	lda	GR1+$100,y
	sta	VIDEO_RAM+$100,y
	lda	GR1+$200,y
	sta	VIDEO_RAM+$200,y
	lda	GR1+$300,y
	sta	VIDEO_RAM+$300,y
	iny
	bne	T51

	ldy	mode
	lda	#$2D
	sta	mode
	jsr	SET
	sty	mode

	ldy	#$0
T52:	lda	GR1+$400,y
	sta	VIDEO_RAM,y
	lda	GR1+$500,y
	sta	VIDEO_RAM+$100,y
	lda	GR1+$600,y
	sta	VIDEO_RAM+$200,y
	lda	GR1+$700,y
	sta	VIDEO_RAM+$300,y
	iny
	bne	T52

	jmp	SET

; ********************* T6 increment singel byte in space caharczer ***********************

TEST6:
	lda	#$2D
	sta	mode
	jsr	SET		; Char RAM 3rd 1k

	inc	$D144
	inc	$D244
	inc	$D1C4
	inc	$D2C4

	lda	#$01
	sta	mode		; Back to last mode
	jmp	SET

GR1:
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 120 , 198 , 129 , 1 
	.DB 0 , 0 , 0 , 0 , 0 , 1 , 1 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 224 , 24 , 12 , 4 , 6 , 6 
	.DB 0 , 3 , 3 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 128 , 64 , 32 , 48 , 24 , 24 
	.DB 0 , 8 , 15 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 248 , 224 , 96 
	.DB 0 , 0 , 0 , 0 , 0 , 195 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 31 , 7 , 3 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 128 , 128 , 128 , 128 , 0 , 0 , 0 , 0 
	.DB 1 , 1 , 3 , 7 , 15 , 30 , 56 , 112 
	.DB 0 , 112 , 232 , 228 , 96 , 96 , 96 , 96 
	.DB 0 , 192 , 224 , 224 , 96 , 96 , 112 , 112 
	.DB 0 , 0 , 224 , 192 , 192 , 192 , 192 , 224 
	.DB 0 , 225 , 241 , 200 , 132 , 194 , 193 , 193 
	.DB 0 , 0 , 129 , 193 , 97 , 49 , 49 , 56 
	.DB 0 , 14 , 29 , 152 , 24 , 28 , 12 , 6 
	.DB 0 , 28 , 26 , 24 , 152 , 88 , 56 , 60 
	.DB 0 , 28 , 14 , 1 , 128 , 128 , 128 , 128 
	.DB 3 , 195 , 227 , 19 , 11 , 7 , 5 , 131 
	.DB 0 , 1 , 3 , 131 , 195 , 195 , 99 , 99 
	.DB 0 , 60 , 99 , 225 , 224 , 224 , 224 , 224 
	.DB 0 , 0 , 128 , 64 , 32 , 48 , 24 , 24 
	.DB 0 , 126 , 120 , 112 , 48 , 48 , 56 , 56 
	.DB 0 , 112 , 232 , 228 , 226 , 96 , 96 , 224 
	.DB 0 , 112 , 120 , 4 , 2 , 1 , 1 , 0 
	.DB 0 , 192 , 48 , 8 , 12 , 4 , 6 , 7 
	.DB 28 , 15 , 14 , 12 , 12 , 14 , 6 , 7 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 96 , 96 , 112 , 112 , 48 , 48 , 48 , 56 
	.DB 0 , 128 , 128 , 128 , 128 , 128 , 192 , 192 
	.DB 3 , 3 , 3 , 1 , 1 , 1 , 1 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 48 , 240 , 0 , 0 
	.DB 112 , 96 , 96 , 32 , 16 , 15 , 0 , 0 
	.DB 112 , 112 , 48 , 48 , 240 , 240 , 0 , 0 
	.DB 120 , 52 , 54 , 51 , 49 , 112 , 0 , 0 
	.DB 224 , 96 , 96 , 98 , 113 , 240 , 48 , 48 
	.DB 192 , 96 , 32 , 48 , 24 , 7 , 0 , 0 
	.DB 248 , 24 , 56 , 56 , 112 , 240 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 28 , 12 , 12 , 12 , 14 , 14 , 0 , 0 
	.DB 128 , 192 , 192 , 192 , 192 , 224 , 0 , 0 
	.DB 129 , 129 , 192 , 64 , 33 , 15 , 0 , 0 
	.DB 113 , 113 , 112 , 112 , 224 , 192 , 0 , 0 
	.DB 96 , 96 , 48 , 16 , 8 , 7 , 0 , 0 
	.DB 28 , 28 , 28 , 156 , 252 , 120 , 0 , 0 
	.DB 60 , 26 , 27 , 25 , 152 , 120 , 0 , 0 
	.DB 112 , 112 , 48 , 49 , 48 , 56 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 3 , 131 , 67 , 35 , 31 , 15 , 0 , 0 
	.DB 6 , 6 , 7 , 3 , 19 , 15 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 128 , 192 , 0 , 0 
	.DB 24 , 24 , 8 , 4 , 7 , 63 , 0 , 0 
	.DB 192 , 192 , 96 , 32 , 60 , 254 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 224 , 112 , 0 , 0 
	.DB 24 , 24 , 8 , 4 , 3 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 255 , 67 , 37 , 25 , 25 , 37 , 67 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 255 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 63 , 34 , 36 , 56 , 56 , 36 , 34 , 33 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 67 , 37 , 25 , 25 , 37 , 67 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 129 , 66 , 36 , 24 , 24 , 36 , 66 , 129 
	.DB 33 , 34 , 36 , 56 , 56 , 36 , 34 , 33 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 129 , 255 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 33 , 63 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
	.DB 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 
